svgPanZoomOutput(outputId, width = "100%", height = "400px")
renderSvgPanZoom(expr, env = parent.frame(), quoted = FALSE)expression that generates a svgPanZoom htmlwidgetenvironment in which to evaluate exprlogical is expr a quoted expression (with quote())?
This is useful if you want to save an expression in a variable.