svgPanZoom-shiny: Shiny bindings for svgPanZoom
Description
Shiny bindings for svgPanZoomUsage
svgPanZoomOutput(outputId, width = "100%", height = "400px")
renderSvgPanZoom(expr, env = parent.frame(), quoted = FALSE)
Arguments
outputId
output variable to read from
width,height
must be a valid CSS unit (like "100which will be coerced to a string and have "px" appended
expr
expression that generates a svgPanZoom htmlwidget
env
environment in which to evaluate expr
quoted
logical is expr a quoted expression (with quote())?
This is useful if you want to save an expression in a variable.